==> MITuna-0.1.tar.gz: MITuna-0.1/tuna/abort.py <==
#!/usr/bin/env python3
###############################################################################
#
# MIT License
#
# Copyright (c) 2022 Advanced Micro Devices, Inc.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
###############################################################################
"""Utility module for checking abort attempts"""

import os


def chk_abort_file(mid, logger, arch=None):
  """Checking presence of abort file to terminate processes immediately"""
  abort_reason = []

  if not arch is None:
    if os.path.exists('/tmp/miopen_abort_{}'.format(arch)):
      abort_reason.append(arch)

  if os.path.exists('/tmp/miopen_abort_mid_{}'.format(mid)):
    abort_reason.append('mid_' + str(mid))
  if abort_reason:
    for reason in abort_reason:
      logger.warning('/tmp/mipen_abort_%s file found, returning', reason)
    return True

  return False

==> MITuna-1.0.tar.gz: MITuna-1.0/tuna/abort.py <==
#!/usr/bin/env python3
###############################################################################
#
# MIT License
#
# Copyright (c) 2022 Advanced Micro Devices, Inc.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
###############################################################################
"""Utility module for checking abort attempts"""

import os


def chk_abort_file(mid, logger, arch=None):
  """Checking presence of abort file to terminate processes immediately"""
  abort_reason = []

  if not arch is None:
    if os.path.exists(f'/tmp/miopen_abort_{arch}'):
      abort_reason.append(arch)

  if os.path.exists(f'/tmp/miopen_abort_mid_{mid}'):
    abort_reason.append('mid_' + str(mid))
  if abort_reason:
    for reason in abort_reason:
      logger.warning('/tmp/mipen_abort_%s file found, returning', reason)
    return True

  return False
